//	cpindexes - for Haiku
//
//	authors, in order of contribution:
//	jonas.sundstrom@kirilla.com
//

// std C includes
#include <stdio.h>
#include <string.h>
#include <errno.h>

// BeOS C includes
#include <fs_info.h>
#include <fs_index.h>
#include <TypeConstants.h>

void	print_help	(void);

int	main (int32 argc, char **argv)
{
	if (argc < 3 || argc > 3)
	{
		print_help();
		return (0);
	}

	status_t	status	=	B_OK;

	dev_t		source_vol_device			=	dev_for_path(".");
	dev_t		target_vol_device			=	dev_for_path(".");
	
	DIR		*	source_index_dir	=	NULL;
	
	source_vol_device	=	dev_for_path(argv[1]);
	target_vol_device	=	dev_for_path(argv[2]);
			
	if (source_vol_device < 0)
	{
		fprintf(stderr, "Volume not found: %s\n", argv[1]);
		return (-1);
	}
	
	if (target_vol_device < 0)
	{
		fprintf(stderr, "Volume not found: %s\n", argv[2]);
		return (-1);
	}
	
	source_index_dir =	fs_open_index_dir(source_vol_device);
	
	if (source_index_dir == NULL)
	{
		fprintf(stderr, "%s: can't open index dir of device %ld\n", argv[0], source_vol_device);
		return (-1);
	}

	while (1)
	{
		dirent	*	index_entry	=	fs_read_index_dir (source_index_dir);
		
		if (index_entry == NULL)
		{
			break;
		}
		else
		{
			// get index info

			index_info	i_info;
						
			status	=	fs_stat_index(source_vol_device, index_entry->d_name, & i_info);
			
			if (status != B_OK)
			{
				printf("%s: fs_stat_index(): (%d) %s\n", argv[0], errno, strerror(errno));
				return (errno);
			}
			
			// Add index to target volume
			
			status = fs_create_index(target_vol_device, index_entry->d_name, i_info.type, 0);
		}
	}
	
	fs_close_index_dir (source_index_dir);

	return (0);
}

void print_help (void)
{
	fprintf (stdout, 
		"\nUsage: cpindexes source target\n"
		"Example: cpindexes /boot /some-other-volume\n\n"
		"This command lets you copy the attribute indexes of one volume to another. "
		"The actual contents of the indexes are not copied - only which attributes are to be indexed. "
		"Only attributes created/modified after the creation of the index are added to the index. "
		"There's a tool called 'reindex' you can use to add files that already existed "
		"at the creation of the index.\n\n"
		"Created by Jonas Sundström of Kirilla.com, for Haiku. Public Domain 2004.\n\n");
		

		
}

